==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/viewer/l10n/uk.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Переглядач",
    "Simple file viewer with slideshow for media" : "Простий переглядач файлів зі слайдшоу для медіа",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажіть свої останні фото та відео зі свят, як у фільмах, погляньте на свій останній роман прямо з Nextcloud, виберіть найкращий GIF зі своєї колекції завдяки прямому попередньому перегляду ваших улюблених файлів і багато іншого!",
    "Your browser does not support audio." : "Ваш браузер не підтримує звук.",
    "Error loading {name}" : "Помилка при завантаженні {name}",
    "Image saved" : "Зображення збережено",
    "Error saving image" : "Помилка збереження зображення",
    "Unsaved changes" : "Незбережені зміни",
    "Drop changes" : "Відкинути зміни",
    "Content of \"{fileName}\"" : "Вміст файлу \"{fileName}\"",
    "Your browser does not support videos." : "Ваш браузер не підтримує відео.",
    "Edit" : "Редагувати",
    "Open sidebar" : "Відкрити бічну панель",
    "Download" : "Завантажити",
    "Delete" : "Вилучити",
    "There is no plugin available to display this file type" : "Немає плагіна для відображення цього типу файлу",
    "View" : "Перегляд",
    "Name" : "Ім'я",
    "Save" : "Зберегти",
    "Save as" : "Зберегти як",
    "Back" : "Назад",
    "Loading …" : "Завантаження …",
    "Reset" : "Скидання",
    "All changes will be lost." : "Усі зміни буде втрачено.",
    "Are you sure you want to continue?" : "Ви впевнені, що бажаєте продовжити?",
    "Cancel" : "Скасувати",
    "Continue" : "Продовжити",
    "Undo" : "Скасувати",
    "Redo" : "Повторити",
    "Show original image" : "Показати вихідне зображення",
    "Zoom in" : "Приближувати",
    "Zoom out" : "Зменшення",
    "Toggle zoom menu" : "Перемкнути меню масштабування",
    "Adjust" : "Налаштувати",
    "Fine-tune" : "Тонка настройка",
    "Filters" : "Фільтри",
    "Watermark" : "Водяний знак",
    "Draw" : "Малювати",
    "Resize" : "Змінити розмір",
    "Invalid image." : "Недійсне зображення.",
    "Error while uploading the image." : "Помилка під час завантаження зображення.",
    "are not images" : "не є зображеннями",
    "is not an image" : "не є зображенням",
    "to be uploaded" : "для завантаження",
    "Crop" : "Урожай",
    "Original" : "Оригінал",
    "Custom" : "Custom",
    "Square" : "Майдан",
    "Landscape" : "Пейзаж",
    "Portrait" : "Портрет",
    "Ellipse" : "Еліпс",
    "Classic TV" : "Класичний TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Стрілка",
    "Blur" : "Розмиття",
    "Brightness" : "Яскравість",
    "Contrast" : "Контраст",
    "Un-flip X" : "Розгорнути по X",
    "Flip X" : "Перевернути X",
    "Un-flip Y" : "Розгорнути по Y",
    "Flip Y" : "Перевернути Y",
    "HSV" : "HSV",
    "Hue" : "Відтінок",
    "Saturation" : "Насиченість",
    "Value" : "Значення",
    "Image" : "Зображення",
    "Importing …" : "Імпорт…",
    "+ Add image" : "+ Додати зображення",
    "Line" : "лінія",
    "Pen" : "Перо",
    "Polygon" : "Багатокутник",
    "Sides" : "Сторони",
    "Rectangle" : "Прямокутник",
    "Corner Radius" : "Радіус кута",
    "Width in pixels" : "Ширина в пікселях",
    "Height in pixels" : "Висота в пікселях",
    "Toggle ratio lock" : "Перемкнути блокування співвідношення",
    "Reset to original image size" : "Відновити початковий розмір зображення",
    "Rotate" : "Обертати",
    "Text" : "Текст",
    "Text spacing" : "Інтервал між текстом",
    "Text alignment" : "Вирівнювання тексту",
    "Font family" : "Сімейство шрифтів",
    "Size" : "Розмір",
    "Letter spacing" : "Інтервал між літерами",
    "Line height" : "Висота лінії",
    "Warmth" : "Тепло",
    "+ Add watermark" : "+ Додати водяний знак",
    "Choose watermark type" : "Виберіть тип водяного знака",
    "Upload watermark" : "Завантажити водяний знак",
    "Add as text" : "Додати як текст",
    "Padding" : "Відступи",
    "Shadow" : "Тінь",
    "Horizontal" : "Горизонтальний",
    "Vertical" : "Вертикальний",
    "Opacity" : "Непрозорість",
    "Position" : "Позиція",
    "Stroke" : "Інсульт",
    "Save image as" : "Зберегти зображення як",
    "Extension" : "Розширення",
    "Name is required." : "Ім'я є обов'язковим.",
    "Quality" : "Якість",
    "Saved image size (width x height)" : "Розмір збереженого зображення (ширина x висота)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Зауважте, що вибрана область кадрування нижча за застосований розмір, що може спричинити погіршення якості",
    "Actual size (100%)" : "Фактичний розмір (100%)",
    "Fit size" : "Підходить за розміром",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажіть фото і відео ваших канікул як кіно, покажіть найяскравіші моменти вашого роману прямо у Nextcloud, оберіть найкращі гіфки з вашої колекції завдяки прямому перегляду ваших файлів, а також багато інших можливостей!"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/viewer/l10n/uk.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Переглядач",
    "Simple file viewer with slideshow for media" : "Простий переглядач файлів зі слайдшоу для зображень",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажіть свої останні фото та відео зі свят, як у фільмах, погляньте на свій останній роман прямо з Nextcloud, виберіть найкращий GIF зі своєї колекції завдяки прямому попередньому перегляду ваших улюблених файлів і багато іншого!",
    "Your browser does not support audio." : "Ваш браузер не підтримує звук.",
    "Error loading {name}" : "Помилка при завантаженні {name}",
    "Image saved" : "Зображення збережено",
    "Error saving image" : "Помилка збереження зображення",
    "Unsaved changes" : "Незбережені зміни",
    "Drop changes" : "Відкинути зміни",
    "Content of \"{fileName}\"" : "Вміст файлу \"{fileName}\"",
    "Your browser does not support videos." : "Ваш браузер не підтримує відео.",
    "Edit" : "Редагувати",
    "Open sidebar" : "Відкрити бічну панель",
    "Download" : "Завантажити",
    "Delete" : "Вилучити",
    "There is no plugin available to display this file type" : "Немає плаґіну для показу цього типу файлу",
    "View" : "Перегляд",
    "Name" : "Ім'я",
    "Save" : "Зберегти",
    "Save as" : "Зберегти як",
    "Back" : "Назад",
    "Loading …" : "Завантаження …",
    "Reset" : "Скидання",
    "All changes will be lost." : "Усі зміни буде втрачено.",
    "Are you sure you want to continue?" : "Ви впевнені, що бажаєте продовжити?",
    "Cancel" : "Скасувати",
    "Continue" : "Продовжити",
    "Undo" : "Скасувати",
    "Redo" : "Повторити",
    "Show original image" : "Показати вихідне зображення",
    "Zoom in" : "Приближувати",
    "Zoom out" : "Зменшення",
    "Toggle zoom menu" : "Перемкнути меню масштабування",
    "Adjust" : "Налаштувати",
    "Fine-tune" : "Тонка настройка",
    "Filters" : "Фільтри",
    "Watermark" : "Водяний знак",
    "Draw" : "Малювати",
    "Resize" : "Змінити розмір",
    "Invalid image." : "Недійсне зображення.",
    "Error while uploading the image." : "Помилка під час завантаження зображення.",
    "are not images" : "не є зображеннями",
    "is not an image" : "не є зображенням",
    "to be uploaded" : "для завантаження",
    "Crop" : "Урожай",
    "Original" : "Оригінал",
    "Custom" : "Custom",
    "Square" : "Майдан",
    "Landscape" : "Пейзаж",
    "Portrait" : "Портрет",
    "Ellipse" : "Еліпс",
    "Classic TV" : "Класичний TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Стрілка",
    "Blur" : "Розмиття",
    "Brightness" : "Яскравість",
    "Contrast" : "Контраст",
    "Un-flip X" : "Розгорнути по X",
    "Flip X" : "Перевернути X",
    "Un-flip Y" : "Розгорнути по Y",
    "Flip Y" : "Перевернути Y",
    "HSV" : "HSV",
    "Hue" : "Відтінок",
    "Saturation" : "Насиченість",
    "Value" : "Значення",
    "Image" : "Зображення",
    "Importing …" : "Імпорт…",
    "+ Add image" : "+ Додати зображення",
    "Line" : "лінія",
    "Pen" : "Перо",
    "Polygon" : "Багатокутник",
    "Sides" : "Сторони",
    "Rectangle" : "Прямокутник",
    "Corner Radius" : "Радіус кута",
    "Width in pixels" : "Ширина в пікселях",
    "Height in pixels" : "Висота в пікселях",
    "Toggle ratio lock" : "Перемкнути блокування співвідношення",
    "Reset to original image size" : "Відновити початковий розмір зображення",
    "Rotate" : "Обертати",
    "Text" : "Текст",
    "Text spacing" : "Інтервал між текстом",
    "Text alignment" : "Вирівнювання тексту",
    "Font family" : "Сімейство шрифтів",
    "Size" : "Розмір",
    "Letter spacing" : "Інтервал між літерами",
    "Line height" : "Висота лінії",
    "Warmth" : "Тепло",
    "+ Add watermark" : "+ Додати водяний знак",
    "Choose watermark type" : "Виберіть тип водяного знака",
    "Upload watermark" : "Завантажити водяний знак",
    "Add as text" : "Додати як текст",
    "Padding" : "Відступи",
    "Shadow" : "Тінь",
    "Horizontal" : "Горизонтальний",
    "Vertical" : "Вертикальний",
    "Opacity" : "Непрозорість",
    "Position" : "Позиція",
    "Stroke" : "Інсульт",
    "Save image as" : "Зберегти зображення як",
    "Extension" : "Розширення",
    "Name is required." : "Ім'я є обов'язковим.",
    "Quality" : "Якість",
    "Saved image size (width x height)" : "Розмір збереженого зображення (ширина x висота)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Зауважте, що вибрана область кадрування нижча за застосований розмір, що може спричинити погіршення якості",
    "Actual size (100%)" : "Фактичний розмір (100%)",
    "Fit size" : "Підходить за розміром",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Покажіть фото і відео ваших канікул як кіно, покажіть найяскравіші моменти вашого роману прямо у Nextcloud, оберіть найкращі гіфки з вашої колекції завдяки прямому перегляду ваших файлів, а також багато інших можливостей!"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
